==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_TW.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定的運算子無效",
    "The given regular expression is invalid" : "指定的正則表達式無效",
    "The given file size is invalid" : "指定的檔案大小無效",
    "The given tag id is invalid" : "指定的標籤 id 無效",
    "The given IP range is invalid" : "指定的 IP 範圍無效",
    "The given IP range is not valid for IPv4" : "指定的 IP 範圍不是有效的 IPv4",
    "The given IP range is not valid for IPv6" : "指定的 IP 範圍不是有效的 IPv6",
    "The given time span is invalid" : "指定的時間範圍無效",
    "The given start time is invalid" : "指定的開始時間無效",
    "The given end time is invalid" : "指定的結束時間無效",
    "The given group does not exist" : "指定的群組不存在",
    "File" : "檔案",
    "File created" : "檔案建立",
    "File updated" : "檔案更新",
    "File renamed" : "檔案重新命名",
    "File deleted" : "檔案刪除",
    "File accessed" : "檔案存取",
    "File copied" : "檔案複製",
    "Tag assigned" : "標籤指派",
    "Someone" : "某人",
    "%s created %s" : "%s 建立了 %s",
    "%s modified %s" : "%s 修改了 %s",
    "%s deleted %s" : "%s 刪除了 %s",
    "%s accessed %s" : "%s 存取了 %s",
    "%s renamed %s" : "%s 重新命名了 %s",
    "%s copied %s" : "%s 複製了 %s",
    "%s assigned %s to %s" : "%s 指派了 %s 給 %s",
    "Operation #%s does not exist" : "操作 #%s 不存在",
    "Entity %s does not exist" : "實體 %s 不存在",
    "Entity %s is invalid" : "實體 %s 無效",
    "No events are chosen." : "未選擇事件。",
    "Entity %s has no event %s" : "實體 %s 沒有事件 %s",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 #%s 無效",
    "At least one check needs to be provided" : "至少需要提供一次檢查",
    "The provided operation data is too long" : "提供的操作資料過長",
    "Invalid check provided" : "提供無效的檢查",
    "Check %s does not exist" : "檢查 %s 不存在",
    "Check %s is invalid" : "檢查 %s 無效",
    "Check %s is not allowed with this entity" : "不允許對此實體進行檢查 %s",
    "The provided check value is too long" : "提供的檢查值過長",
    "Check #%s does not exist" : "檢查 #%s 不存在",
    "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
    "Flow" : "流程",
    "Nextcloud workflow engine" : "Nextcloud 工作流程引擎",
    "Select a filter" : "選取過濾條件",
    "Select a comparator" : "選取比較程式",
    "Remove filter" : "移除過濾條件",
    "Audio" : "音訊",
    "Folder" : "資料夾",
    "Images" : "圖片",
    "Office documents" : "Office 文件",
    "PDF documents" : "PDF 文件",
    "Video" : "影片",
    "Custom MIME type" : "自訂 MIME 類型",
    "Custom mimetype" : "自訂 mimetype",
    "Select a file type" : "選取檔案類型",
    "e.g. httpd/unix-directory" : "例如：httpd/unix-directory",
    "Please enter a valid time span" : "請輸入有效的時間範圍",
    "Files WebDAV" : "檔案 WebDAV",
    "Custom URL" : "自訂 URL",
    "Select a request URL" : "選取請求 URL",
    "Android client" : "Android 客戶端",
    "iOS client" : "iOS 客戶端",
    "Desktop client" : "桌面客戶端",
    "Thunderbird & Outlook addons" : "Thunderbird 與 Outlook 附加元件",
    "Custom user agent" : "自訂使用者代理字串",
    "Select a user agent" : "選取使用者代理字串",
    "Select groups" : "選擇群組",
    "Groups" : "群組",
    "Type to search for group …" : "輸入以搜尋群組……",
    "Select a trigger" : "選取觸發條件",
    "At least one event must be selected" : "必須至少選取一個事件",
    "Add new flow" : "新增新流程",
    "The configuration is invalid" : "組態設定無效",
    "Active" : "啟動",
    "Save" : "儲存",
    "When" : "當",
    "and" : "與",
    "Add a new filter" : "新增過濾條件",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "Available flows" : "可用的流程",
    "For details on how to write your own flow, check out the development documentation." : "關於如何編寫自己的流程，請看開發文件。",
    "No flows installed" : "未安裝流程",
    "Ask your administrator to install new flows." : "請向您的管理員要求安裝新流程。",
    "More flows" : "更多流程",
    "Browse the App Store" : "瀏覽應用程式商店",
    "Show less" : "顯示較少",
    "Show more" : "顯示更多",
    "Configured flows" : "已設定的流程",
    "Your flows" : "您的流程",
    "No flows configured" : "未設定流程",
    "matches" : "符合",
    "does not match" : "不符合",
    "is" : "是",
    "is not" : "不是",
    "File name" : "檔案名稱",
    "File MIME type" : "檔案 MIME 類型",
    "File size (upload)" : "檔案大小（上傳）",
    "less" : "小於",
    "less or equals" : "小於或等於",
    "greater or equals" : "大於或等於",
    "greater" : "大於",
    "Request remote address" : "請求遠端地址",
    "matches IPv4" : "符合 IPv4",
    "does not match IPv4" : "不符合 IPv4",
    "matches IPv6" : "符合 IPv6",
    "does not match IPv6" : "不符合 IPv6",
    "File system tag" : "檔案系統標籤",
    "is tagged with" : "標記為",
    "is not tagged with" : "没有標記為",
    "Request URL" : "請求 URL",
    "Request time" : "請求時間",
    "between" : "介於",
    "not between" : "不介於",
    "Request user agent" : "請求使用者代理字串",
    "Group membership" : "群組成員資格",
    "is member of" : "是成員的群組",
    "is not member of" : "不是成員的群組"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_TW.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定的運算子無效",
    "The given regular expression is invalid" : "指定的正則表達式無效",
    "The given file size is invalid" : "指定的檔案大小無效",
    "The given tag id is invalid" : "指定的標籤 id 無效",
    "The given IP range is invalid" : "指定的 IP 範圍無效",
    "The given IP range is not valid for IPv4" : "指定的 IP 範圍不是有效的 IPv4",
    "The given IP range is not valid for IPv6" : "指定的 IP 範圍不是有效的 IPv6",
    "The given time span is invalid" : "指定的時間範圍無效",
    "The given start time is invalid" : "指定的開始時間無效",
    "The given end time is invalid" : "指定的結束時間無效",
    "The given group does not exist" : "指定的群組不存在",
    "File" : "檔案",
    "File created" : "檔案建立",
    "File updated" : "檔案更新",
    "File renamed" : "檔案重新命名",
    "File deleted" : "檔案刪除",
    "File accessed" : "檔案存取",
    "File copied" : "檔案複製",
    "Tag assigned" : "標籤指派",
    "Someone" : "某人",
    "%s created %s" : "%s 建立了 %s",
    "%s modified %s" : "%s 修改了 %s",
    "%s deleted %s" : "%s 刪除了 %s",
    "%s accessed %s" : "%s 存取了 %s",
    "%s renamed %s" : "%s 重新命名了 %s",
    "%s copied %s" : "%s 複製了 %s",
    "%s assigned %s to %s" : "%s 指派了 %s 給 %s",
    "Operation #%s does not exist" : "操作 #%s 不存在",
    "Entity %s does not exist" : "實體 %s 不存在",
    "Entity %s is invalid" : "實體 %s 無效",
    "No events are chosen." : "未選擇事件。",
    "Entity %s has no event %s" : "實體 %s 沒有事件 %s",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 #%s 無效",
    "At least one check needs to be provided" : "至少需要提供一次檢查",
    "The provided operation data is too long" : "提供的操作資料過長",
    "Invalid check provided" : "提供無效的檢查",
    "Check %s does not exist" : "檢查 %s 不存在",
    "Check %s is invalid" : "檢查 %s 無效",
    "Check %s is not allowed with this entity" : "不允許對此實體進行檢查 %s",
    "The provided check value is too long" : "提供的檢查值過長",
    "Check #%s does not exist" : "檢查 #%s 不存在",
    "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
    "Flow" : "流程",
    "Nextcloud workflow engine" : "Nextcloud 工作流程引擎",
    "Select a filter" : "選取過濾條件",
    "Select a comparator" : "選取比較程式",
    "Remove filter" : "移除過濾條件",
    "Audio" : "音訊",
    "Folder" : "資料夾",
    "Images" : "圖片",
    "Office documents" : "Office 文件",
    "PDF documents" : "PDF 文件",
    "Video" : "影片",
    "Custom MIME type" : "自訂 MIME 類型",
    "Custom mimetype" : "自訂 mimetype",
    "Select a file type" : "選取檔案類型",
    "e.g. httpd/unix-directory" : "例如：httpd/unix-directory",
    "Please enter a valid time span" : "請輸入有效的時間範圍",
    "Files WebDAV" : "檔案 WebDAV",
    "Custom URL" : "自訂 URL",
    "Select a request URL" : "選取請求 URL",
    "Android client" : "Android 客戶端",
    "iOS client" : "iOS 客戶端",
    "Desktop client" : "桌面客戶端",
    "Thunderbird & Outlook addons" : "Thunderbird 與 Outlook 附加元件",
    "Custom user agent" : "自訂使用者代理字串",
    "Select a user agent" : "選取使用者代理字串",
    "Select groups" : "選擇群組",
    "Groups" : "群組",
    "Type to search for group …" : "輸入以搜尋群組 ……",
    "Select a trigger" : "選取觸發條件",
    "At least one event must be selected" : "必須至少選取一個事件",
    "Add new flow" : "新增新流程",
    "The configuration is invalid" : "組態設定無效",
    "Active" : "啟動",
    "Save" : "儲存",
    "When" : "當",
    "and" : "與",
    "Add a new filter" : "新增過濾條件",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "Available flows" : "可用的流程",
    "For details on how to write your own flow, check out the development documentation." : "關於如何編寫自己的流程，請看開發文件。",
    "No flows installed" : "未安裝流程",
    "Ask your administrator to install new flows." : "請向您的管理員要求安裝新流程。",
    "More flows" : "更多流程",
    "Browse the App Store" : "瀏覽應用程式商店",
    "Show less" : "顯示較少",
    "Show more" : "顯示更多",
    "Configured flows" : "已設定的流程",
    "Your flows" : "您的流程",
    "No flows configured" : "未設定流程",
    "matches" : "符合",
    "does not match" : "不符合",
    "is" : "是",
    "is not" : "不是",
    "File name" : "檔案名稱",
    "File MIME type" : "檔案 MIME 類型",
    "File size (upload)" : "檔案大小（上傳）",
    "less" : "小於",
    "less or equals" : "小於或等於",
    "greater or equals" : "大於或等於",
    "greater" : "大於",
    "Request remote address" : "請求遠端地址",
    "matches IPv4" : "符合 IPv4",
    "does not match IPv4" : "不符合 IPv4",
    "matches IPv6" : "符合 IPv6",
    "does not match IPv6" : "不符合 IPv6",
    "File system tag" : "檔案系統標籤",
    "is tagged with" : "標記為",
    "is not tagged with" : "没有標記為",
    "Request URL" : "請求 URL",
    "Request time" : "請求時間",
    "between" : "介於",
    "not between" : "不介於",
    "Request user agent" : "請求使用者代理字串",
    "Group membership" : "群組成員資格",
    "is member of" : "是成員的群組",
    "is not member of" : "不是成員的群組",
    "Type to search for group …" : "輸入以搜尋群組……"
},
"nplurals=1; plural=0;");
